@@ -18,6 +18,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include <KLocalizedString>
 #include <QDebug>
 #if QT_VERSION < 0x050500
 # define qInfo qDebug
@@ -38,7 +39,7 @@ Configuration::Configuration()
 	if ((value >= 0) && (value <= StartupLastValue)) {
 		startupDisplayMode = static_cast<StartupDisplayMode>(value);
 	} else {
-		qInfo() << "Configuration::Configuration: unknown startup display mode" << value;
+		qWarning("Unknown startup display mode %d", value);
 	}
 
 	shortSkipDuration =
@@ -70,8 +71,7 @@ void Configuration::setStartupDisplayMode(int newStartupDisplayMode)
 		KSharedConfig::openConfig()->group("MainWindow").writeEntry("StartupDisplayMode",
 			static_cast<int>(startupDisplayMode));
 	} else {
-		qInfo() << "Configuration::setStartupDisplayMode: unknown startup display mode" <<
-			newStartupDisplayMode;
+		qWarning("Unknown startup display mode %d", newStartupDisplayMode);
 	}
 }
 
